@@ -112,7 +112,7 @@ draw_window_on_pixbuf (GtkWidget *widget)
   gtk_window_get_size (GTK_WINDOW (widget), &width, &height);
 
   visual = gtk_widget_get_visual (widget);
-  pixmap = gdk_pixmap_new (NULL, width, height, visual->depth);
+  pixmap = gdk_pixmap_new (NULL, width, height, gdk_visual_get_depth (visual));
   gdk_drawable_set_colormap (GDK_DRAWABLE (pixmap), gtk_widget_get_colormap (widget));
 
   window = gtk_widget_get_window (widget);
@@ -319,7 +319,7 @@ create_meta_theme_pixbuf (ThemeThumbnailData *theme_thumbnail_data)
   g_object_unref (icon);
   gtk_widget_destroy (window);
   meta_theme_free (theme);
-  gdk_pixmap_unref (pixmap);
+  g_object_unref (pixmap);
 
   return pixbuf;
 }
@@ -386,7 +386,7 @@ create_gtk_theme_pixbuf (ThemeThumbnailData *theme_thumbnail_data)
                                     GDK_INTERP_BILINEAR);
   g_object_unref (pixbuf);
   gtk_widget_destroy (window);
-  gdk_pixmap_unref (pixmap);
+  g_object_unref (pixmap);
 
   return retval;
 }
@@ -462,7 +462,7 @@ create_metacity_theme_pixbuf (ThemeThumbnailData *theme_thumbnail_data)
 
   gtk_widget_destroy (window);
   meta_theme_free (theme);
-  gdk_pixmap_unref (pixmap);
+  g_object_unref (pixmap);
 
   return retval;
 }
